@@ -37,7 +37,7 @@ class Event:
     name = Column(String(50), nullable=False)
     data = Column(JSONB(), nullable=False)
     event_metadata = Column(JSONB(), nullable=False)
-    created_at = Column(DateTime(timezone=True), nullable=False, index=True)
+    created_at = Column(DateTime(), nullable=False, index=True)
 
 
 class Snapshot:
@@ -49,13 +49,13 @@ class Snapshot:
     name = Column(String(50), nullable=False)
     data = Column(JSONB(), nullable=False)
     event_metadata = Column(JSONB(), nullable=False)
-    created_at = Column(DateTime(timezone=True), nullable=False)
+    created_at = Column(DateTime(), nullable=False)
 
 
 class OutboxEntry:
     __tablename__ = "event_sourcery_outbox_entries"
 
     id = Column(BigInteger().with_variant(Integer(), "sqlite"), primary_key=True)
-    created_at = Column(DateTime(timezone=True), nullable=False, index=True)
+    created_at = Column(DateTime(), nullable=False, index=True)
     data = Column(JSONB(), nullable=False)
     tries_left = Column(Integer(), nullable=False, server_default="3")
