@@ -1,6 +1,5 @@
 from dataclasses import dataclass
-from datetime import datetime
-from typing import Callable, Iterator, Tuple, Union, cast
+from typing import Callable, Iterator, Union
 
 from sqlalchemy import delete
 from sqlalchemy import event as sa_event
@@ -10,11 +9,10 @@ from sqlalchemy.exc import NoResultFound
 from sqlalchemy.orm import Session
 
 from event_sourcery.dto.raw_event_dict import RawEventDict
-from event_sourcery.exceptions import ConcurrentStreamWriteError, NotFound
-from event_sourcery.interfaces.storage_strategy import EntryId, StorageStrategy
+from event_sourcery.exceptions import ConcurrentStreamWriteError
+from event_sourcery.interfaces.storage_strategy import StorageStrategy
 from event_sourcery.types.stream_id import StreamId
 from event_sourcery_sqlalchemy.models import Event as EventModel
-from event_sourcery_sqlalchemy.models import OutboxEntry
 from event_sourcery_sqlalchemy.models import Snapshot as SnapshotModel
 from event_sourcery_sqlalchemy.models import Stream as StreamModel
 
@@ -46,35 +44,47 @@ class SqlAlchemyStorageStrategy(StorageStrategy):
                     metadata=event.event_metadata,
                 )
 
-    def fetch_events(self, stream_id: StreamId) -> Tuple[list[RawEventDict], int]:
+    def fetch_events(
+        self, stream_id: StreamId, start: int | None = None, stop: int | None = None
+    ) -> list[RawEventDict]:
         events_stmt = (
-            select(EventModel, StreamModel.version)
-            .join(StreamModel, EventModel.stream_id == StreamModel.uuid)
+            select(EventModel)
             .filter(EventModel.stream_id == stream_id)
-            .order_by(EventModel.created_at)
+            .order_by(EventModel.version)
         )
-        events: list[Tuple[Union[EventModel, SnapshotModel], int]]
+        if start is not None:
+            events_stmt = events_stmt.filter(EventModel.version >= start)
+
+        if stop is not None:
+            events_stmt = events_stmt.filter(EventModel.version < stop)
+
+        events: list[Union[EventModel, SnapshotModel]]
         try:
             snapshot_stmt = (
-                select(SnapshotModel, StreamModel.version)
-                .join(StreamModel, SnapshotModel.stream_id == StreamModel.uuid)
+                select(SnapshotModel)
                 .filter(SnapshotModel.stream_id == stream_id)
                 .order_by(SnapshotModel.created_at.desc())
                 .limit(1)
             )
-            latest_snapshot, stream_version = self._session.execute(snapshot_stmt).one()
+            if start is not None:
+                snapshot_stmt = snapshot_stmt.filter(SnapshotModel.version >= start)
+
+            if stop is not None:
+                snapshot_stmt = snapshot_stmt.filter(SnapshotModel.version < stop)
+
+            latest_snapshot = self._session.execute(snapshot_stmt).scalars().one()
         except NoResultFound:
-            events = self._session.execute(events_stmt).all()
+            events = self._session.execute(events_stmt).scalars().all()
         else:
             events_stmt = events_stmt.filter(
-                EventModel.created_at > latest_snapshot.created_at
+                EventModel.version > latest_snapshot.version
             )
-            events = [[latest_snapshot, stream_version]] + self._session.execute(
+            events = [latest_snapshot] + self._session.execute(
                 events_stmt
-            ).all()
+            ).scalars().all()
 
         if not events:
-            raise NotFound
+            return []
 
         raw_dict_events = [
             RawEventDict(
@@ -86,9 +96,9 @@ class SqlAlchemyStorageStrategy(StorageStrategy):
                 data=event.data,
                 metadata=event.event_metadata,
             )
-            for event, stream_version in events
+            for event in events
         ]
-        return raw_dict_events, events[-1][1]
+        return raw_dict_events
 
     def ensure_stream(self, stream_id: StreamId, expected_version: int) -> None:
         ensure_stream_stmt = (
@@ -155,40 +165,5 @@ class SqlAlchemyStorageStrategy(StorageStrategy):
         )
         self._session.execute(delete_stream_stmt)
 
-    def put_into_outbox(self, events: list[RawEventDict]) -> None:
-        rows = []
-        for event in events:
-            as_dict = dict(event)
-            created_at = cast(datetime, as_dict["created_at"])
-            as_dict["created_at"] = created_at.isoformat()
-            as_dict["uuid"] = str(as_dict["uuid"])
-            as_dict["stream_id"] = str(as_dict["stream_id"])
-            rows.append(
-                {
-                    "created_at": datetime.utcnow(),
-                    "data": as_dict,
-                }
-            )
-        self._session.execute(insert(OutboxEntry), rows)
-
-    def outbox_entries(self, limit: int) -> Iterator[Tuple[EntryId, RawEventDict]]:
-        stmt = (
-            select(OutboxEntry)
-            .filter(OutboxEntry.tries_left > 0)
-            .order_by(OutboxEntry.id)
-            .limit(limit)
-            .with_for_update(skip_locked=True)
-        )
-        entries = self._session.execute(stmt).scalars().all()
-        return ((entry.id, entry.data) for entry in entries)
-
-    def decrease_tries_left(self, entry_id: EntryId) -> None:
-        entry = self._session.query(OutboxEntry).get(entry_id)
-        entry.tries_left -= 1
-
-    def remove_from_outbox(self, entry_id: EntryId) -> None:
-        entry = self._session.query(OutboxEntry).get(entry_id)
-        self._session.delete(entry)
-
     def run_after_commit(self, callback: Callable[[], None]) -> None:
         sa_event.listen(self._session, "after_commit", lambda _session: callback())
